@@ -90,6 +90,8 @@ remoteVenue=@@{REMOTEVENUE}
 probeId=@@{PROBEID}
 probeProgram=@@{PROBEPROGRAM}
 nCores=@@{NCORES}
+nGpus=@@{NGPUS}
+memory=@@{MEMORY}
 wallTime=@@{WALLTIME}
 inputs="@@{INPUTS}"
 preSubmitCommands="@@{PRESUBMITCOMMANDS}"
@@ -97,17 +99,28 @@ postSubmitCommands="@@{POSTSUBMITCOMMANDS}"
 
 coreArg=
 if [ ${nCores} -gt -1 ] ; then
-   coreArg="-nCpus ${nCores}"
+   coreArg="--nCpus ${nCores}"
 fi
 
-wallTimeArg="-wallTime 10"
+gpuArg=
+if [ ${nGpus} -gt -1 ] ; then
+   gpuArg="--nGpus ${nGpus}"
+fi
+
+memoryArg=
+if [ ${memory} -gt -1 ] ; then
+   memoryArg="--memory ${memory}"
+fi
+
+wallTimeArg="--wallTime 10"
 if [ -n "${wallTime}" ] ; then
    wallTimeArg="-w ${wallTime}"
 fi
+
 x509SubmitProxyArg=
-if [ -f ~/.globus/probe.proxy ] ; then
-   x509SubmitProxyArg="--x509SubmitProxy ~/.globus/probe.proxy"
-fi
+#if [ -f ~/.globus/probe.proxy ] ; then
+#   x509SubmitProxyArg="--x509SubmitProxy ~/.globus/probe.proxy"
+#fi
 
 #echo gridProbeRoot=${gridProbeRoot}
 #echo probeDirectory=${probeDirectory}
@@ -115,6 +128,8 @@ fi
 #echo probeId=${probeId}
 #echo probeProgram=${probeProgram}
 #echo nCores=${nCores}
+#echo nGpus=${nGpus}
+#echo memory=${memory}
 #echo wallTime=${wallTime}
 #echo inputs=${inputs}
 #echo preSubmitCommands=${preSubmitCommands}
@@ -191,6 +206,8 @@ EOF
 
       ${SUBMITPATH} --venue ${remoteVenue} \
                     ${coreArg} \
+                    ${gpuArg} \
+                    ${memoryArg} \
                     ${wallTimeArg} \
                     ${x509SubmitProxyArg} \
                     --disableProbeCheck \
@@ -552,6 +569,8 @@ exit ${exitStatus}
                   siteName = sitePattern.match(record).group(2)
                   self.probeSites[siteName] = {'probeProgram':'./probegridsite.sh', \
                                                'nCores':-1, \
+                                               'nGpus':-1, \
+                                               'memory':-1, \
                                                'maximumTimeToProbeCompletion':-1, \
                                                'wallTime':10, \
                                                'inputs':[], \
@@ -922,6 +941,8 @@ exit ${exitStatus}
                   substitutions["PROBEID"]            = "%09d" % (probe.id)
                   substitutions["PROBEPROGRAM"]       = self.probeSites[probe.destination]['probeProgram']
                   substitutions["NCORES"]             = self.probeSites[probe.destination]['nCores']
+                  substitutions["NGPUS"]              = self.probeSites[probe.destination]['nGpus']
+                  substitutions["MEMORY"]             = self.probeSites[probe.destination]['memory']
                   substitutions["WALLTIME"]           = self.probeSites[probe.destination]['wallTime']
                   substitutions["INPUTS"]             = inputs
                   substitutions["PRESUBMITCOMMANDS"]  = preSubmitCommands
@@ -934,6 +955,7 @@ exit ${exitStatus}
                   except KeyError as e:
                      probeSiteShellScript = ""
                      self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+                     self.logger.log(logging.ERROR,getLogMessage("in rawProbeSiteShellTemplate\n"))
                   except TypeError:
                      probeSiteShellScript = ""
                      self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % \
